@@ -1,7 +1,7 @@
 // qjackctlAboutForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -69,12 +69,12 @@ qjackctlAboutForm::qjackctlAboutForm (
 	list << tr("JACK Session support disabled.");
 #endif
 #ifndef CONFIG_ALSA_SEQ
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	list << tr("ALSA/MIDI sequencer support disabled.");
 #endif
 #endif
 #ifndef CONFIG_DBUS
-#if !defined(WIN32)
+#if !defined(__WIN32__) && !defined(_WIN32) && !defined(WIN32)
 	list << tr("D-Bus interface support disabled.");
 #endif
 #endif
