@@ -1,7 +1,7 @@
 // qjackctlConnectAlias.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ public:
 	QString clientName() const;
 
 	// Client name matcher.
-	bool matchClientName(const QString& sClientName);
+	bool matchClientName(const QString& sClientName) const;
 
 	// Client aliasing methods.
 	const QString& clientAlias() const;
