@@ -1,7 +1,7 @@
 // qjackctlJackConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -157,6 +157,23 @@ void qjackctlJackPort::updatePortName ( bool bRename )
 }
 
 
+// Tooltip text builder (virtual override).
+QString qjackctlJackPort::tooltip (void) const
+{
+	jack_latency_range_t latency_range;
+
+	jack_port_get_latency_range(m_pJackPort,
+		client()->isReadable() ? JackCaptureLatency : JackPlaybackLatency,
+		&latency_range);
+
+	QString sLatency = QString::number(latency_range.min);
+	if (latency_range.max > latency_range.min)
+		sLatency +=  '-' + QString::number(latency_range.max);
+
+	return QObject::tr("%1 (%2 frames)").arg(portName()).arg(sLatency);
+}
+
+
 //----------------------------------------------------------------------
 // class qjackctlJackClient -- Jack client list item.
 //
@@ -235,6 +252,7 @@ void qjackctlJackClient::updateClientName ( bool bRename )
 				&& !sPrettyName.isEmpty() && bRename) {
 				removePrettyName(pJackClient, client_uuid);
 			}
+			::jack_free((void *) pszClientUuid);
 		}
 		setClientText(sClientNameEx, bRenameEnabled);
 	}
