@@ -1,7 +1,7 @@
 // qjackctlJackConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -67,6 +67,9 @@ public:
 	// Pretty/display name method (virtual override).
 	void updatePortName(bool bRename = false);
 
+	// Tooltip text builder (virtual override).
+	QString tooltip() const;
+
 private:
 
 	// Instance variables.
