@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -481,7 +481,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_pSetup = pSetup;
 
 	// Avoid dirty this all up.
-	m_iDirtySetup++;
+	++m_iDirtySetup;
 
 	// Load combo box history...
 	m_pSetup->loadComboBoxHistory(m_ui.ServerPrefixComboBox);
@@ -656,13 +656,10 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 
 	// Load preset list...
 	resetPresets();
-	setComboBoxCurrentText(m_ui.PresetComboBox,
-		m_pSetup->sDefPreset);
-	// Finally, load default settings...
-	changePreset(m_ui.PresetComboBox->currentText());
+	updateCurrentPreset();
 
 	// We're clean now.
-	m_iDirtySetup--;
+	--m_iDirtySetup;
 	stabilizeForm();
 }
 
@@ -816,6 +813,18 @@ void qjackctlSetupForm::resetPresets (void)
 }
 
 
+void qjackctlSetupForm::updateCurrentPreset (void)
+{
+   // Have current preset changed anyhow?
+   if (m_pSetup && m_pSetup->sDefPreset != m_sPreset) {
+	   ++m_iDirtySetup;
+	   setComboBoxCurrentText(m_ui.PresetComboBox, m_pSetup->sDefPreset);
+	   changePreset(m_ui.PresetComboBox->currentText());
+	   --m_iDirtySetup;
+   }
+}
+
+
 void qjackctlSetupForm::changeCurrentPreset ( const QString& sPreset )
 {
 	if (m_iDirtySetup > 0)
@@ -833,18 +842,19 @@ void qjackctlSetupForm::changeCurrentPreset ( const QString& sPreset )
 			QMessageBox::Cancel)) {
 		case QMessageBox::Save:
 			savePreset(m_sPreset);
-			m_iDirtySetup++;
+			++m_iDirtySetup;
 			resetPresets();
 			setComboBoxCurrentText(m_ui.PresetComboBox, sPreset);
-			m_iDirtySetup--;
+			--m_iDirtySetup;
+			// Fall thru...
 		case QMessageBox::Discard:
 			m_iDirtySettings = 0;
 			break;
 		default: // Cancel...
-			m_iDirtySetup++;
+			++m_iDirtySetup;
 			resetPresets();
 			setComboBoxCurrentText(m_ui.PresetComboBox, m_sPreset);
-			m_iDirtySetup--;
+			--m_iDirtySetup;
 			return;
 		}
 	}
@@ -859,10 +869,10 @@ void qjackctlSetupForm::saveCurrentPreset (void)
 
 	if (savePreset(sPreset)) {
 		// Reset preset combobox list.
-		m_iDirtySetup++;
+		++m_iDirtySetup;
 		resetPresets();
 		setComboBoxCurrentText(m_ui.PresetComboBox, sPreset);
-		m_iDirtySetup--;
+		--m_iDirtySetup;
 		// Reset dirty flag.
 		m_iDirtySettings = 0;
 		stabilizeForm();
@@ -886,12 +896,12 @@ void qjackctlSetupForm::deleteCurrentPreset (void)
 	if (deletePreset(sPreset)) {
 		// Reset preset combobox list,
 		// and load a new available preset..
-		m_iDirtySetup++;
+		++m_iDirtySetup;
 		int iItem = m_ui.PresetComboBox->currentIndex();
 		resetPresets();
 		m_ui.PresetComboBox->setCurrentIndex(iItem);
 		changePreset(m_ui.PresetComboBox->currentText());
-		m_iDirtySetup--;
+		--m_iDirtySetup;
 		// Take care that maybe it was the default one...
 		if (m_pSetup->sDefPreset == sPreset)
 			m_pSetup->sDefPreset = m_sPreset;
@@ -1417,7 +1427,7 @@ void qjackctlSetupForm::settingsChanged (void)
 	if (m_iDirtySetup > 0)
 		return;
 
-	m_iDirtySettings++;
+	++m_iDirtySettings;
 	stabilizeForm();
 }
 
